summaryrefslogtreecommitdiff
path: root/src/map_func.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/map_func.h')
-rw-r--r--src/map_func.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/map_func.h b/src/map_func.h
index a4b3991da..ff539b8af 100644
--- a/src/map_func.h
+++ b/src/map_func.h
@@ -383,15 +383,15 @@ static inline TileIndex TileAddByDiagDir(TileIndex tile, DiagDirection dir)
* A callback function type for searching tiles.
*
* @param tile The tile to test
* @param data additional data for the callback function to use
* @return A boolean value, depend on the definition of the function.
*/
-typedef bool TestTileOnSearchProc(TileIndex tile, uint32 data);
+typedef bool TestTileOnSearchProc(TileIndex tile, void *user_data);
/**
* Searches for some cirumstances of a tile around a given tile with a helper function.
*/
-bool CircularTileSearch(TileIndex *tile, uint size, TestTileOnSearchProc proc, uint32 data);
+bool CircularTileSearch(TileIndex *tile, uint size, TestTileOnSearchProc proc, void *user_data);
/**
* Get a random tile out of a given seed.
@@ -383,15 +383,15 @@ static inline TileIndex TileAddByDiagDir(TileIndex tile, DiagDirection dir)
*
* @param tile The tile to test
- * @param data additional data for the callback function to use
+ * @param user_data additional data for the callback function to use
* @return A boolean value, depend on the definition of the function.
*/